@@ -84,6 +84,8 @@ func Registry() *Command {
 		loginRegDesc, Writer)
 	AddIntFlag(cmdRegistryLogin, doctl.ArgRegistryExpirySeconds, "", 0,
 		"The length of time the registry credentials will be valid for in seconds. By default, the credentials do not expire.")
+	AddBoolFlag(cmdRegistryLogin, doctl.ArgRegistryReadOnly, "", false,
+		"If true, the DigitalOcean API token generated by the login command will be read-only, causing any push operations to fail. By default, the API token is read-write.")
 
 	logoutRegDesc := "This command logs Docker out of the private container registry, revoking access to it."
 	cmdRunRegistryLogout := CmdBuilder(cmd, RunRegistryLogout, "logout", "Log out Docker from a container registry",
@@ -379,8 +381,13 @@ func RunRegistryLogin(c *CmdConfig) error {
 	if err != nil {
 		return err
 	}
+	readOnly, err := c.Doit.GetBool(c.NS, doctl.ArgRegistryReadOnly)
+	if err != nil {
+		return err
+	}
+
 	regCredReq := godo.RegistryDockerCredentialsRequest{
-		ReadWrite: true,
+		ReadWrite: !readOnly,
 	}
 	if expirySeconds != 0 {
 		regCredReq.ExpirySeconds = godo.Int(expirySeconds)
